<?php
/*
* Plugin Name: Remove New User in Multisite
* Plugin URI: 
* Description: Hides the Add New User option in multisite setups
* Version: 0.1
* Author: UBC CMS
* Author URI:http://cms.ubc.ca
*
* 
* This program is free software; you can redistribute it and/or modify it under the terms of the GNU
* General Public License as published by the Free Software Foundation; either version 2 of the License,
* or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
* even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*
* You should have received a copy of the GNU General Public License along with this program; if not, write
* to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
*
* @license http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
*/
// require_once(ABSPATH.'/wp-admin/admin.php');
// require_once(ABSPATH . 'wp-admin/includes/admin.php');
// require_once(ABSPATH.'/wp-admin/admin-header.php' );

/**
 * CTLT_Remove_New_User class.
 */
class CTLT_Remove_New_User {
	
	/**
	 * __construct function.
	 *
	 * @access public
	 * @return void
	 */
	public function __construct() {
		/* Register shortcodes on 'init'. */
		add_action('admin_menu', array( &$this, 'hide_menu'));
	}

	public function hide_menu() {
		global $plugin_page;
		remove_submenu_page('users.php', 'user-new.php');
		add_submenu_page('users.php', get_admin_page_title(), 'Add New', 'manage_network_users', 
			$plugin_page, array($this, 'add_back_menu'));
	}

	public function add_back_menu() {
		$title = __('Add New User');
		$parent_file = 'users.php';

		$do_both = false;
		if ( is_multisite() && current_user_can('promote_users') && current_user_can('create_users') )
			$do_both = true;

		$help = '<p>';// . __('To add a new user to your site, fill in the form on this screen and click the Add New User button at the bottom.') . '</p>';

		if ( is_multisite() ) {
			$help .= '<p>' . __('Because this is a multisite installation, you may add accounts that already exist on the Network by specifying a username or email, and defining a role. For more options, such as specifying a password, you have to be a Network Administrator and use the hover link under an existing user&#8217;s name to Edit the user profile under Network Admin > All Users.') . '</p>' .
			'<p>' . __('New users will receive an email letting them know they&#8217;ve been added as a user for your site. This email will also contain their password. Check the box if you don&#8217;t want the user to receive a welcome email.') . '</p>';
		} else {
			$help .= '<p>' . __('You must assign a password to the new user, which they can change after logging in. The username, however, cannot be changed.') . '</p>' .
			'<p>' . __('New users will receive an email letting them know they&#8217;ve been added as a user for your site. By default, this email will also contain their password. Uncheck the box if you don&#8217;t want the password to be included in the welcome email.') . '</p>';
		}

		$help .= '<p>' . __('Remember to click the Add New User button at the bottom of this screen when you are finished.') . '</p>';

		get_current_screen()->add_help_tab( array(
			'id'      => 'overview',
			'title'   => __('Overview'),
			'content' => $help,
		) );

		get_current_screen()->add_help_tab( array(
		'id'      => 'user-roles',
		'title'   => __('User Roles'),
		'content' => '<p>' . __('Here is a basic overview of the different user roles and the permissions associated with each one:') . '</p>' .
						'<ul>' .
						'<li>' . __('Administrators have access to all the administration features.') . '</li>' .
						'<li>' . __('Editors can publish posts, manage posts as well as manage other people&#8217;s posts, etc.') . '</li>' .
						'<li>' . __('Authors can publish and manage their own posts, and are able to upload files.') . '</li>' .
						'<li>' . __('Contributors can write and manage their posts but not publish posts or upload media files.') . '</li>' .
						'<li>' . __('Subscribers can read comments/comment/receive newsletters, etc. but cannot create regular site content.') . '</li>' .
						'</ul>'
		) );

		get_current_screen()->set_help_sidebar(
		    '<p><strong>' . __('For more information:') . '</strong></p>' .
		    '<p>' . __('<a href="http://codex.wordpress.org/Users_Add_New_Screen" target="_blank">Documentation on Adding New Users</a>') . '</p>' .
		    '<p>' . __('<a href="http://wordpress.org/support/" target="_blank">Support Forums</a>') . '</p>'
		);

		wp_enqueue_script('wp-ajax-response');
		wp_enqueue_script('user-profile');

		if ( is_multisite() && current_user_can( 'promote_users' ) && ! wp_is_large_network( 'users' )
			&& ( is_super_admin() || apply_filters( 'autocomplete_users_for_site_admins', false ) )
		) {
			wp_enqueue_script( 'user-suggest' );
		}

		// require_once( 'admin-header.php' );

		if ( isset($_GET['update']) ) {
			$messages = array();
			if ( is_multisite() ) {
				switch ( $_GET['update'] ) {
					case "newuserconfirmation":
						$messages[] = __('Invitation email sent to new user. A confirmation link must be clicked before their account is created.');
						break;
					case "add":
						$messages[] = __('Invitation email sent to user. A confirmation link must be clicked for them to be added to your site.');
						break;
					case "addnoconfirmation":
						$messages[] = __('User has been added to your site.');
						break;
					case "addexisting":
						$messages[] = __('That user is already a member of this site.');
						break;
					case "does_not_exist":
						$messages[] = __('The requested user does not exist.');
						break;
					case "enter_email":
						$messages[] = __('Please enter a valid email address.');
						break;
				}
			} else {
				if ( 'add' == $_GET['update'] )
					$messages[] = __('User added.');
			}
		}
		
		echo '<div class="wrap">';
		screen_icon(); 
		echo '<h2 id="add-new-user">';
		if ( current_user_can( 'create_users' ) ) {
			echo _x( 'Add New User', 'user' );
		} elseif ( current_user_can( 'promote_users' ) ) {
			echo _x( 'Add Existing User', 'user' );
		}

		echo '</h2>';

		if ( isset($errors) && is_wp_error( $errors ) ) :
			echo '<div class="error">';
			echo '<ul>';	
			foreach ( $errors->get_error_messages() as $err )
				echo "<li>$err</li>\n";
			
			echo '</ul>
			</div>';
		endif;

		if ( ! empty( $messages ) ) {
			foreach ( $messages as $msg )
				echo '<div id="message" class="updated"><p>' . $msg . '</p></div>';
		}

		if ( isset($add_user_errors) && is_wp_error( $add_user_errors ) ) :
			echo '<div class="error">';
			foreach ( $add_user_errors->get_error_messages() as $message )
				echo "<p>$message</p>";

			echo '</div>';
		endif;
		echo '<div id="ajax-response"></div>';

		if ( is_multisite() ) {
			if ( $do_both )
				echo '<h3 id="add-existing-user">' . __('Add Existing User') . '</h3>';
			if ( !is_super_admin() ) {
				_e( 'Enter the email address of an existing user on this network to invite them to this site. That person will be sent an email asking them to confirm the invite.' );
				$label = __('E-mail');
			} else {
				_e( 'Enter the email address or username of an existing user on this network to invite them to this site. That person will be sent an email asking them to confirm the invite.' );
				$label = __('E-mail or Username');
			}
		}

		echo '
		<form action="" method="post" name="adduser" id="adduser" class="validate"'.do_action('user_new_form_tag').'>';
		echo '<input name="action" type="hidden" value="adduser" />';
		wp_nonce_field( 'add-user', '_wpnonce_add-user' );

		echo '
		<table class="form-table">
			<tr class="form-field form-required">
				<th scope="row"><label for="adduser-email">'. $label .'</label></th>
				<td><input name="email" type="text" id="adduser-email" class="wp-suggest-user" value="" /></td>
			</tr>
			<tr class="form-field">
				<th scope="row"><label for="adduser-role">'.__('Role').'</label></th>
				<td><select name="role" id="adduser-role">';
					wp_dropdown_roles( get_option('default_role') );
		echo '		</select>
				</td>
			</tr>';
		if ( is_super_admin() ) {
			echo '<tr>
				<th scope="row"><label for="adduser-noconfirmation">'. __('Skip Confirmation Email') .'</label></th>
				<td><label for="adduser-noconfirmation"><input type="checkbox" name="noconfirmation" id="adduser-noconfirmation" value="1" /> '. _e( 'Add the user without sending them a confirmation email.' ).'</label></td>
			</tr>';
		} 
		echo '</table>';
		submit_button( __( 'Add Existing User '), 'primary', 'adduser', true, array( 'id' => 'addusersub' ) );
		echo '</form>';
		
	}
}
new CTLT_Remove_New_User();